package com.zzsmart.qomo.kn.cost.manage.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zzsmart.qomo.kn.cost.manage.entity.AppSceneCostPurchaseRecord;
import com.zzsmart.qomo.kn.cost.manage.service.IAppSceneCostPurchaseRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

/**
 * @Description: app_scene_cost_purchase_record
 * @Author: jeecg-boot
 * @Date: 2024-09-08
 * @Version: V1.0
 */
//@Api(tags = "app_scene_cost_purchase_record")
@RestController
@RequestMapping("//appSceneCostPurchaseRecord")
@Slf4j
public class AppSceneCostPurchaseRecordController extends JeecgController<AppSceneCostPurchaseRecord, IAppSceneCostPurchaseRecordService> {
    @Autowired
    private IAppSceneCostPurchaseRecordService appSceneCostPurchaseRecordService;

    /**
     * 分页列表查询
     *
     * @param appSceneCostPurchaseRecord
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "app_scene_cost_purchase_record-分页列表查询")
    @ApiOperation(value = "app_scene_cost_purchase_record-分页列表查询", notes = "app_scene_cost_purchase_record-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<AppSceneCostPurchaseRecord>> queryPageList(AppSceneCostPurchaseRecord appSceneCostPurchaseRecord, @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo, @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize, HttpServletRequest req) {
        QueryWrapper<AppSceneCostPurchaseRecord> queryWrapper = QueryGenerator.initQueryWrapper(appSceneCostPurchaseRecord, req.getParameterMap());
        Page<AppSceneCostPurchaseRecord> page = new Page<AppSceneCostPurchaseRecord>(pageNo, pageSize);
        IPage<AppSceneCostPurchaseRecord> pageList = appSceneCostPurchaseRecordService.page(page, queryWrapper);
        return Result.OK(pageList);
    }

    /**
     * 添加
     *
     * @param appSceneCostPurchaseRecord
     * @return
     */
    @AutoLog(value = "app_scene_cost_purchase_record-添加")
    @ApiOperation(value = "app_scene_cost_purchase_record-添加", notes = "app_scene_cost_purchase_record-添加")
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:add")
    @PostMapping(value = "/add")
    public Result<String> add(@RequestBody AppSceneCostPurchaseRecord appSceneCostPurchaseRecord) {
        appSceneCostPurchaseRecordService.save(appSceneCostPurchaseRecord);
        return Result.OK("添加成功！");
    }

    /**
     * 编辑
     *
     * @param appSceneCostPurchaseRecord
     * @return
     */
    @AutoLog(value = "app_scene_cost_purchase_record-编辑")
    @ApiOperation(value = "app_scene_cost_purchase_record-编辑", notes = "app_scene_cost_purchase_record-编辑")
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:edit")
    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
    public Result<String> edit(@RequestBody AppSceneCostPurchaseRecord appSceneCostPurchaseRecord) {
        appSceneCostPurchaseRecordService.updateById(appSceneCostPurchaseRecord);
        return Result.OK("编辑成功!");
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "app_scene_cost_purchase_record-通过id删除")
    @ApiOperation(value = "app_scene_cost_purchase_record-通过id删除", notes = "app_scene_cost_purchase_record-通过id删除")
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:delete")
    @DeleteMapping(value = "/delete")
    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
        appSceneCostPurchaseRecordService.removeById(id);
        return Result.OK("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "app_scene_cost_purchase_record-批量删除")
    @ApiOperation(value = "app_scene_cost_purchase_record-批量删除", notes = "app_scene_cost_purchase_record-批量删除")
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:deleteBatch")
    @DeleteMapping(value = "/deleteBatch")
    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        this.appSceneCostPurchaseRecordService.removeByIds(Arrays.asList(ids.split(",")));
        return Result.OK("批量删除成功!");
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    //@AutoLog(value = "app_scene_cost_purchase_record-通过id查询")
    @ApiOperation(value = "app_scene_cost_purchase_record-通过id查询", notes = "app_scene_cost_purchase_record-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<AppSceneCostPurchaseRecord> queryById(@RequestParam(name = "id", required = true) String id) {
        AppSceneCostPurchaseRecord appSceneCostPurchaseRecord = appSceneCostPurchaseRecordService.getById(id);
        if (appSceneCostPurchaseRecord == null) {
            return Result.error("未找到对应数据");
        }
        return Result.OK(appSceneCostPurchaseRecord);
    }

    /**
     * 导出excel
     *
     * @param request
     * @param appSceneCostPurchaseRecord
     */
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, AppSceneCostPurchaseRecord appSceneCostPurchaseRecord) {
        return super.exportXls(request, appSceneCostPurchaseRecord, AppSceneCostPurchaseRecord.class, "app_scene_cost_purchase_record");
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_purchase_record:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, AppSceneCostPurchaseRecord.class);
    }

}
