package com.zzsmart.qomo.kn.cost.manage.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zzsmart.qomo.kn.cost.manage.entity.AppSceneCostMaterialBom;
import com.zzsmart.qomo.kn.cost.manage.service.IAppSceneCostMaterialBomService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @Description: app_scene_cost_material_bom
 * @Author: jeecg-boot
 * @Date: 2024-08-02
 * @Version: V1.0
 */
@RequestMapping("//cost-material-bom")
@Api(tags="cost-标准成本-bom信息")
@RestController
@Slf4j
public class AppSceneCostMaterialBomController extends JeecgController<AppSceneCostMaterialBom, IAppSceneCostMaterialBomService> {
    @Autowired
    private IAppSceneCostMaterialBomService costMaterialBomService;
    /**
     * 分页列表查询
     *
     * @param costMaterialBom
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    //@AutoLog(value = "app_scene_cost_standard_version-分页列表查询")
    @ApiOperation(value="物料bom分页列表查询", notes="物料bom分页列表查询")
    @GetMapping(value = "/pageList")
    public Result<IPage<AppSceneCostMaterialBom>> queryPageList(AppSceneCostMaterialBom costMaterialBom,
                                                        @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
                                                        @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
                                                        HttpServletRequest req) {
        QueryWrapper<AppSceneCostMaterialBom> queryWrapper = QueryGenerator.initQueryWrapper(costMaterialBom, req.getParameterMap());
        Page<AppSceneCostMaterialBom> page = new Page<AppSceneCostMaterialBom>(pageNo, pageSize);
        IPage<AppSceneCostMaterialBom> pageList = costMaterialBomService.page(page, queryWrapper);
        return Result.OK(pageList);
    }
    /**
     * 列表查询
     *
     * @return
     */
    @ApiOperation(value="物料bom列表查询", notes="物料bom列表查询")
    @GetMapping(value = "/list")
    public Result<List<AppSceneCostMaterialBom>> queryList(@RequestParam(name = "materialNumber",required = false) String materialNumber) {
        List<AppSceneCostMaterialBom> list = costMaterialBomService.queryListResult(materialNumber);
        return Result.OK(list);
    }

//    /**
//     * 分页列表查询
//     *
//     * @param appSceneCostMaterialBom
//     * @param pageNo
//     * @param pageSize
//     * @param req
//     * @return
//     */
//    //@AutoLog(value = "app_scene_cost_material_bom-分页列表查询")
//    @ApiOperation(value = "app_scene_cost_material_bom-分页列表查询", notes = "app_scene_cost_material_bom-分页列表查询")
//    @GetMapping(value = "/list")
//    public Result<IPage<AppSceneCostMaterialBom>> queryPageList(AppSceneCostMaterialBom appSceneCostMaterialBom,
//                                                                @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
//                                                                @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
//                                                                HttpServletRequest req) {
//        QueryWrapper<AppSceneCostMaterialBom> queryWrapper = QueryGenerator.initQueryWrapper(appSceneCostMaterialBom, req.getParameterMap());
//        Page<AppSceneCostMaterialBom> page = new Page<AppSceneCostMaterialBom>(pageNo, pageSize);
//        IPage<AppSceneCostMaterialBom> pageList = appSceneCostMaterialBomService.page(page, queryWrapper);
//        return Result.OK(pageList);
//    }
//
//    /**
//     * 添加
//     *
//     * @param appSceneCostMaterialBom
//     * @return
//     */
//    @AutoLog(value = "app_scene_cost_material_bom-添加")
//    @ApiOperation(value = "app_scene_cost_material_bom-添加", notes = "app_scene_cost_material_bom-添加")
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:add")
//    @PostMapping(value = "/add")
//    public Result<String> add(@RequestBody AppSceneCostMaterialBom appSceneCostMaterialBom) {
//        appSceneCostMaterialBomService.save(appSceneCostMaterialBom);
//        return Result.OK("添加成功！");
//    }
//
//    /**
//     * 编辑
//     *
//     * @param appSceneCostMaterialBom
//     * @return
//     */
//    @AutoLog(value = "app_scene_cost_material_bom-编辑")
//    @ApiOperation(value = "app_scene_cost_material_bom-编辑", notes = "app_scene_cost_material_bom-编辑")
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:edit")
//    @RequestMapping(value = "/edit", method = {RequestMethod.PUT, RequestMethod.POST})
//    public Result<String> edit(@RequestBody AppSceneCostMaterialBom appSceneCostMaterialBom) {
//        appSceneCostMaterialBomService.updateById(appSceneCostMaterialBom);
//        return Result.OK("编辑成功!");
//    }
//
//    /**
//     * 通过id删除
//     *
//     * @param id
//     * @return
//     */
//    @AutoLog(value = "app_scene_cost_material_bom-通过id删除")
//    @ApiOperation(value = "app_scene_cost_material_bom-通过id删除", notes = "app_scene_cost_material_bom-通过id删除")
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:delete")
//    @DeleteMapping(value = "/delete")
//    public Result<String> delete(@RequestParam(name = "id", required = true) String id) {
//        appSceneCostMaterialBomService.removeById(id);
//        return Result.OK("删除成功!");
//    }
//
//    /**
//     * 批量删除
//     *
//     * @param ids
//     * @return
//     */
//    @AutoLog(value = "app_scene_cost_material_bom-批量删除")
//    @ApiOperation(value = "app_scene_cost_material_bom-批量删除", notes = "app_scene_cost_material_bom-批量删除")
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:deleteBatch")
//    @DeleteMapping(value = "/deleteBatch")
//    public Result<String> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
//        this.appSceneCostMaterialBomService.removeByIds(Arrays.asList(ids.split(",")));
//        return Result.OK("批量删除成功!");
//    }
//
//    /**
//     * 通过id查询
//     *
//     * @param id
//     * @return
//     */
//    //@AutoLog(value = "app_scene_cost_material_bom-通过id查询")
//    @ApiOperation(value = "app_scene_cost_material_bom-通过id查询", notes = "app_scene_cost_material_bom-通过id查询")
//    @GetMapping(value = "/queryById")
//    public Result<AppSceneCostMaterialBom> queryById(@RequestParam(name = "id", required = true) String id) {
//        AppSceneCostMaterialBom appSceneCostMaterialBom = appSceneCostMaterialBomService.getById(id);
//        if (appSceneCostMaterialBom == null) {
//            return Result.error("未找到对应数据");
//        }
//        return Result.OK(appSceneCostMaterialBom);
//    }
//
//    /**
//     * 导出excel
//     *
//     * @param request
//     * @param appSceneCostMaterialBom
//     */
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:exportXls")
//    @RequestMapping(value = "/exportXls")
//    public ModelAndView exportXls(HttpServletRequest request, AppSceneCostMaterialBom appSceneCostMaterialBom) {
//        return super.exportXls(request, appSceneCostMaterialBom, AppSceneCostMaterialBom.class, "app_scene_cost_material_bom");
//    }
//
//    /**
//     * 通过excel导入数据
//     *
//     * @param request
//     * @param response
//     * @return
//     */
//    //@RequiresPermissions("com.zzsmart.qomo.kn.cost.manage:app_scene_cost_material_bom:importExcel")
//    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
//    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
//        return super.importExcel(request, response, AppSceneCostMaterialBom.class);
//    }

}
